@@ -7,8 +7,7 @@
 #include "appgroupmanager.h"
 #include <QStandardItemModel>
 
-namespace apps
-{
+namespace apps {
 class AppItemModel : public QStandardItemModel
 {
 public:
@@ -26,10 +25,20 @@ public:
         DockedRole,
         OnDesktopRole,
         AutoStartRole,
-        GroupRole,
+        AppTypeRole,
+        XLingLongRole,
+        IdRole,
+        XCreatedByRole,
+        ExecsRole,
     };
     Q_ENUM(Roles)
 
+    enum AppTypes {
+        AppItemType,
+        FolderItemType,
+    };
+    Q_ENUM(AppTypes)
+
     // This is different from the menu-spec Main Categories list.
     enum DDECategories {
         Internet, // 网络模式
