@@ -6,6 +6,9 @@
 #include "pluginmanagerintegration_p.h"
 #include "constants.h"
 
+#include <DGuiApplicationHelper>
+#include <DPlatformTheme>
+
 #include <cstdint>
 
 #include <QtWaylandCompositor/QWaylandSurface>
@@ -15,7 +18,92 @@
 #include <QJsonObject>
 #include <QJsonParseError>
 
-PluginSurface::PluginSurface(PluginManager* manager, const QString& pluginId, const QString& itemKey, const QString &displayName, int pluginFlags, int pluginType, int sizePolicy, QWaylandSurface *surface, const QWaylandResource &resource)
+#define protected public
+#include <private/qwaylandcompositor_p.h>
+#undef protected
+#include <qpa/qwindowsysteminterface_p.h>
+#include <private/qwlqtkey_p.h>
+#include <private/qwlqttouch_p.h>
+
+DGUI_USE_NAMESPACE
+
+PluginScaleManager::PluginScaleManager(QWaylandCompositor *compositor)
+    : QWaylandCompositorExtensionTemplate(compositor)
+    , m_compositor(compositor)
+{
+}
+
+void PluginScaleManager::setPluginScale(const uint32_t &scale)
+{
+    if (scale == m_scale)
+        return;
+    m_scale = scale;
+    if (!m_compositor)
+        return;
+
+    auto outputs = m_compositor->outputs();
+    std::for_each(outputs.begin(), outputs.end(), [this](auto *output) {
+        // 120 is base of fractional scale.
+        output->setScaleFactor(std::ceil(m_scale / 120.0));
+    });
+
+    Q_EMIT pluginScaleChanged(m_scale);
+}
+
+uint32_t PluginScaleManager::pluginScale()
+{
+    return m_scale;
+}
+
+void PluginScaleManager::initialize()
+{
+    QWaylandCompositorExtensionTemplate::initialize();
+    QWaylandCompositor *compositor = static_cast<QWaylandCompositor *>(extensionContainer());
+    Q_ASSERT(compositor);
+
+    init(compositor->display(), 1);
+    m_compositor = compositor;
+    connect(compositor, &QWaylandCompositor::outputAdded, this, [this](auto *output) {
+        output->setScaleFactor(std::ceil(m_scale / 120.0));
+    });
+}
+
+void PluginScaleManager::wp_fractional_scale_manager_v1_get_fractional_scale(Resource *resource, uint32_t id, struct ::wl_resource *surface)
+{
+    QWaylandSurface *qwaylandSurface = QWaylandSurface::fromResource(surface);
+    QWaylandResource shellSurfaceResource(
+        wl_resource_create(resource->client(), &::wp_fractional_scale_v1_interface, wl_resource_get_version(resource->handle), id));
+    auto pluginScale = new PluginScale(this, qwaylandSurface, shellSurfaceResource);
+    pluginScale->send_preferred_scale(m_scale);
+}
+
+PluginScale::PluginScale(PluginScaleManager *manager, QWaylandSurface *surface, const QWaylandResource &resource)
+{
+    setParent(manager);
+    init(resource.resource());
+    setExtensionContainer(surface);
+    QWaylandCompositorExtension::initialize();
+
+    connect(manager, &PluginScaleManager::pluginScaleChanged, this, [this](uint32_t scale) {
+        send_preferred_scale(scale);
+    });
+}
+
+void PluginScale::wp_fractional_scale_v1_destroy(Resource *resource)
+{
+    Q_UNUSED(resource)
+    deleteLater();
+}
+
+PluginSurface::PluginSurface(PluginManager *manager,
+                             const QString &pluginId,
+                             const QString &itemKey,
+                             const QString &displayName,
+                             int pluginFlags,
+                             int pluginType,
+                             int sizePolicy,
+                             QWaylandSurface *surface,
+                             const QWaylandResource &resource)
     : m_manager(manager)
     , m_surface(surface)
     , m_itemKey(itemKey)
@@ -25,12 +113,12 @@ PluginSurface::PluginSurface(PluginManager* manager, const QString& pluginId, co
     , m_pluginType(pluginType)
     , m_sizePolicy(sizePolicy)
     , m_margins(0)
+    , m_height(1)
+    , m_width(1)
 {
     init(resource.resource());
     setExtensionContainer(surface);
     QWaylandCompositorExtension::initialize();
-
-    connect(surface, &QWaylandSurface::bufferSizeChanged, this, &PluginSurface::sizeChanged);
 }
 
 QWaylandQuickShellIntegration* PluginSurface::createIntegration(QWaylandQuickShellSurfaceItem *item)
@@ -73,9 +161,14 @@ uint32_t PluginSurface::pluginSizePolicy () const
     return m_sizePolicy;
 }
 
-QSize PluginSurface::pluginSize() const
+int PluginSurface::height() const
 {
-    return m_surface->bufferSize() / qApp->devicePixelRatio();
+    return m_height;
+}
+
+int PluginSurface::width() const
+{
+    return m_width;
 }
 
 QString PluginSurface::dccIcon() const
@@ -115,6 +208,12 @@ void PluginSurface::plugin_dcc_icon(Resource *resource, const QString &icon)
     m_dccIcon = icon;
 }
 
+void PluginSurface::plugin_request_shutdown(Resource *resource, const QString &type)
+{
+    Q_UNUSED(resource);
+    Q_EMIT m_manager->requestShutdown(type);
+}
+
 void PluginSurface::plugin_close_quick_panel(Resource *resource) {
     qInfo() << "close_quick_panel";
     Q_EMIT m_manager->pluginCloseQuickPanelPopup();
@@ -150,12 +249,38 @@ void PluginSurface::setGlobalPos(const QPoint &pos)
     send_raw_global_pos(p.x(), p.y());
 }
 
-PluginPopup::PluginPopup(PluginManager* manager, const QString &pluginId, const QString &itemKey, int x, int y, int popupType, QWaylandSurface *surface, const QWaylandResource &resource)
+void PluginSurface::plugin_source_size(Resource *resource, int32_t width, int32_t height)
+{
+    Q_UNUSED(resource);
+    if (width == 0 || height == 0)
+        return;
+
+    if (height != m_height) {
+        m_height = height;
+        Q_EMIT heightChanged();
+    }
+
+    if (width != m_width) {
+        m_width = width;
+        Q_EMIT widthChanged();
+    }
+}
+
+PluginPopup::PluginPopup(PluginManager *manager,
+                         const QString &pluginId,
+                         const QString &itemKey,
+                         int x,
+                         int y,
+                         int popupType,
+                         QWaylandSurface *surface,
+                         const QWaylandResource &resource)
     : m_manager(manager)
     , m_surface(surface)
     , m_pluginId(pluginId)
     , m_itemKey(itemKey)
     , m_popupType(popupType)
+    , m_height(1)
+    , m_width(1)
 {
     init(resource.resource());
     setExtensionContainer(surface);
@@ -214,6 +339,16 @@ void PluginPopup::setY(int32_t y)
     Q_EMIT yChanged();
 }
 
+int PluginPopup::height() const
+{
+    return m_height;
+}
+
+int PluginPopup::width() const
+{
+    return m_width;
+}
+
 int32_t PluginPopup::popupType() const
 {
     return m_popupType;
@@ -237,15 +372,58 @@ void PluginPopup::plugin_popup_destroy(Resource *resource)
 {
     wl_resource_destroy(resource->handle);
 }
+
+void PluginPopup::plugin_popup_source_size(Resource *resource, int32_t width, int32_t height)
+{
+    Q_UNUSED(resource);
+    if (width == 0 || height == 0)
+        return;
+
+    if (height != m_height) {
+        m_height = height;
+        Q_EMIT heightChanged();
+    }
+
+    if (width != m_width) {
+        m_width = width;
+        Q_EMIT widthChanged();
+    }
+}
+
 PluginManager::PluginManager(QWaylandCompositor *compositor)
     : QWaylandCompositorExtensionTemplate(compositor)
 {
+    auto theme = DGuiApplicationHelper::instance()->applicationTheme();
+    QObject::connect(theme, &DPlatformTheme::fontNameChanged, this, &PluginManager::onFontChanged);
+    QObject::connect(theme, &DPlatformTheme::fontPointSizeChanged, this, &PluginManager::onFontChanged);
+    QObject::connect(theme, &DPlatformTheme::activeColorChanged, this, &PluginManager::onActiveColorChanged);
+    QObject::connect(theme, &DPlatformTheme::darkActiveColorChanged, this, &PluginManager::onActiveColorChanged);
+    QObject::connect(theme, &DPlatformTheme::themeNameChanged, this, &PluginManager::onThemeChanged);
+    QObject::connect(theme, &DPlatformTheme::iconThemeNameChanged, this, &PluginManager::onThemeChanged);
 }
 
 void PluginManager::initialize()
 {
     QWaylandCompositorExtensionTemplate::initialize();
     QWaylandCompositor *compositor = static_cast<QWaylandCompositor *>(extensionContainer());
+
+    // ###(zccrs): 在dde-shell中不要使用QWaylandCompositor的event handler，它会对key event进行
+    // 特殊处理，会丢弃掉原生事件的信息，仅根据 native scan key code 通过xkb生成原始key event向
+    // dde-shell 传递，这会导致需要状态切换后进行输入的字符丢失信息，比如外部环境打开NumLock后，小键盘
+    // 的数字输入会被event handler转成原始事件，丢失了NumLock的开关信息。
+    // dde-shell不是一个独立的合成器，所以不需要额外处理key event，需要遵守原始事件中的NumLock状态
+    // 确保输出数字时在dde-shell的wayland客户端中接收到的也是数字。
+    auto eventHandler = QWaylandCompositorPrivate::get(compositor)->eventHandler.get();
+    if (eventHandler == QWindowSystemInterfacePrivate::eventHandler) {
+        QWindowSystemInterfacePrivate::removeWindowSystemEventhandler(eventHandler);
+    }
+
+    // 只创建就行
+    auto qtKey = new QtWayland::QtKeyExtensionGlobal(compositor);
+    qtKey->setParent(compositor);
+    auto qtTouch = new QtWayland::TouchExtensionGlobal(compositor);
+    qtTouch->setParent(compositor);
+
     init(compositor->display(), 1);
 }
 
@@ -349,6 +527,10 @@ void PluginManager::plugin_manager_v1_create_plugin(Resource *resource, const QS
 
     send_position_changed(resource->handle, m_dockPosition);
     send_color_theme_changed(resource->handle, m_dockColorTheme);
+    auto theme = DGuiApplicationHelper::instance()->applicationTheme();
+    send_active_color_changed(resource->handle, theme->activeColor().name(), theme->darkActiveColor().name());
+    send_font_changed(resource->handle, theme->fontName(), theme->fontPointSize());
+    send_theme_changed(resource->handle, theme->themeName(), theme->iconThemeName());
 
     auto plugin = new PluginSurface(this, pluginId, itemKey, display_name, plugin_flags, type, size_policy, qwaylandSurface, shellSurfaceResource);
     m_pluginSurfaces << plugin;
@@ -437,6 +619,40 @@ void PluginManager::removePluginSurface(PluginSurface *plugin)
     m_pluginSurfaces.removeAll(plugin);
 }
 
+void PluginManager::onFontChanged()
+{
+    foreachPluginSurface([this](Resource *source) {
+        auto theme = DGuiApplicationHelper::instance()->applicationTheme();
+        send_font_changed(source->handle, theme->fontName(), theme->fontPointSize());
+    });
+}
+
+void PluginManager::onActiveColorChanged()
+{
+    foreachPluginSurface([this](Resource *source) {
+        auto theme = DGuiApplicationHelper::instance()->applicationTheme();
+        send_active_color_changed(source->handle, theme->activeColor().name(), theme->darkActiveColor().name());
+    });
+}
+
+void PluginManager::onThemeChanged()
+{
+    foreachPluginSurface([this](Resource *source) {
+        auto theme = DGuiApplicationHelper::instance()->applicationTheme();
+        send_theme_changed(source->handle, theme->themeName(), theme->iconThemeName());
+    });
+}
+
+void PluginManager::foreachPluginSurface(PluginSurfaceCallback callback)
+{
+    foreach (PluginSurface *plugin, m_pluginSurfaces) {
+        Resource *target = resourceMap().value(plugin->surface()->waylandClient());
+        if (target) {
+            callback(target);
+        }
+    }
+}
+
 QString PluginManager::dockSizeMsg() const
 {
     if (m_dockSize.isEmpty())
