@@ -33,6 +33,9 @@ public:
     QModelIndex mapToSource(const QModelIndex &proxyIndex) const override;
     QModelIndex mapFromSource(const QModelIndex &sourceIndex) const override;
 
+private:
+    QHash<int, QByteArray> createRoleNames() const;
+
 private:
     QAbstractItemModel* m_minor;
 
@@ -40,4 +43,6 @@ private:
     QMap<QPair<int, int> ,QPair<int, int>> m_indexMap;
     // Hash table map role in this model to role in origin model.
     QHash<int, int> m_minorRolesMap;
+
+    QHash<int, QByteArray> m_roleNames;
 };
