@@ -18,7 +18,6 @@
 #include <cstdint>
 #include <iterator>
 
-
 namespace dock {
 ForeignToplevelManager::ForeignToplevelManager(TreeLandWindowMonitor* monitor)
     : QWaylandClientExtensionTemplate<ForeignToplevelManager>(1)
@@ -80,6 +79,7 @@ void TreeLandDockPreviewContext::treeland_dock_preview_context_v1_leave()
 
 TreeLandWindowMonitor::TreeLandWindowMonitor(QObject* parent)
     :AbstractWindowMonitor(parent)
+    , m_fullscreenState(false)
 {
 }
 
@@ -118,6 +118,10 @@ void TreeLandWindowMonitor::presentWindows(QList<uint32_t> windows)
 
 void TreeLandWindowMonitor::showItemPreview(const QPointer<AppItem> &item, QObject* relativePositionItem, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
 {
+    if (!m_foreignToplevelManager->isActive()) {
+        return;
+    }
+
     if (m_dockPreview.isNull()) {
         auto window = qobject_cast<QWindow*>(relativePositionItem);
         if (!window) return;
@@ -126,6 +130,9 @@ void TreeLandWindowMonitor::showItemPreview(const QPointer<AppItem> &item, QObje
 
         auto context = m_foreignToplevelManager->get_dock_preview_context(waylandWindow->wlSurface());
         m_dockPreview.reset(new TreeLandDockPreviewContext(context));
+        connect(window, &QWindow::visibleChanged, m_dockPreview.get(), [this]() {
+            m_dockPreview.reset();
+        });
     }
 
     auto windows = item->getAppendWindows();
@@ -168,8 +175,21 @@ void TreeLandWindowMonitor::handleForeignToplevelHandleAdded()
         m_windows.insert(id, window);
     }
 
+    connect(window.data(), &AbstractWindow::stateChanged, this, [=] {
+        for (auto w: m_windows) {
+            if (w->isFullscreen() && !m_fullscreenState) {
+                m_fullscreenState = true;
+                emit windowFullscreenChanged(true);
+                return;
+            }
+        }
+        if (m_fullscreenState) {
+            m_fullscreenState = false;
+            emit windowFullscreenChanged(false);
+        }
+    });
+
     window->setForeignToplevelHandle(handle);
-    trackWindow(window.get());
 
     if (window->isReady())
         Q_EMIT AbstractWindowMonitor::windowAdded(static_cast<QPointer<AbstractWindow>>(window.get()));
@@ -184,7 +204,6 @@ void TreeLandWindowMonitor::handleForeignToplevelHandleRemoved()
 
     auto id = handle->id();
     auto window = m_windows.value(id, nullptr);
-    destroyWindow(window.get());
 
     if (window) {
         m_windows.remove(id);
