@@ -3,7 +3,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "appitem.h"
-#include "dsglobal.h"
 #include "x11utils.h"
 #include "x11window.h"
 #include "x11preview.h"
@@ -11,12 +10,7 @@
 #include "x11windowmonitor.h"
 #include "abstractwindowmonitor.h"
 
-#include <memory>
-
-#include <thread>
 #include <cstdint>
-#include <iterator>
-#include <algorithm>
 #include <xcb/xcb.h>
 #include <xcb/xproto.h>
 
@@ -54,7 +48,7 @@ X11WindowMonitor::X11WindowMonitor(QObject* parent)
 {
     monitor = this;
     connect(this, &X11WindowMonitor::windowMapped, this, &X11WindowMonitor::onWindowMapped);
-    connect(this, &X11WindowMonitor::windowDestoried, this, &X11WindowMonitor::onWindowDestoried);
+    connect(this, &X11WindowMonitor::windowDestroyed, this, &X11WindowMonitor::onWindowDestroyed);
     connect(this, &X11WindowMonitor::windowPropertyChanged, this, &X11WindowMonitor::onWindowPropertyChanged);
 }
 
@@ -115,6 +109,7 @@ void X11WindowMonitor::showItemPreview(const QPointer<AppItem> &item, QObject* r
 
     if (m_windowPreview.isNull()) {
         m_windowPreview.reset(new X11WindowPreviewContainer(this));
+        m_windowPreview->windowHandle()->setTransientParent(qobject_cast<QWindow *>(relativePositionItem));
     }
 
     m_windowPreview->showPreview(item,qobject_cast<QWindow*>(relativePositionItem), previewXoffset, previewYoffset, direction);
@@ -161,7 +156,7 @@ void X11WindowMonitor::onWindowMapped(xcb_window_t xcb_window)
     Q_EMIT AbstractWindowMonitor::windowAdded(static_cast<QPointer<AbstractWindow>>(window.get()));
 }
 
-void X11WindowMonitor::onWindowDestoried(xcb_window_t xcb_window)
+void X11WindowMonitor::onWindowDestroyed(xcb_window_t xcb_window)
 {
     auto window = m_windows.value(xcb_window, nullptr);
     if (window) {
@@ -196,6 +191,8 @@ void X11WindowMonitor::onWindowPropertyChanged(xcb_window_t window, xcb_atom_t a
         x11Window->updateWindowTypes();
     } else if (atom == X11->getAtomByName("_MOTIF_WM_HINTS")) {
         x11Window->updateMotifWmHints();
+    } else if (atom == X11->getAtomByName("WM_CLASS")) {
+        x11Window->updateIdentify();
     }
 
     auto appitem = x11Window->getAppItem();
@@ -223,7 +220,7 @@ void X11WindowMonitor::handleRootWindowClientListChanged()
 
     for (auto alreadyOpenedWindow : m_windows.keys()) {
         if (!currentOpenedWindowList.contains(alreadyOpenedWindow)) {
-            windowDestoried(alreadyOpenedWindow);
+            Q_EMIT windowDestroyed(alreadyOpenedWindow);
         }
     }
 
