@@ -35,11 +35,11 @@
     </message>
     <message>
         <source>Top</source>
-        <translation>parte superior</translation>
+        <translation>Arriba</translation>
     </message>
     <message>
         <source>Bottom</source>
-        <translation>parte inferior</translation>
+        <translation>Abajo</translation>
     </message>
     <message>
         <source>Right</source>
@@ -65,5 +65,9 @@
         <source>Dock Settings</source>
         <translation>Ajustes del muelle</translation>
     </message>
+    <message>
+        <source>Lock the Dock</source>
+        <translation>Bloquear muelle</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
