@@ -63,7 +63,11 @@
     </message>
     <message>
         <source>Dock Settings</source>
-        <translation>Paneeli asetukset</translation>
+        <translation>Telakan asetukset</translation>
+    </message>
+    <message>
+        <source>Lock the Dock</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
