@@ -65,5 +65,9 @@
         <source>Dock Settings</source>
         <translation>Настройки Dock</translation>
     </message>
+    <message>
+        <source>Lock the Dock</source>
+        <translation>Заблокировать док</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
