@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN" sourcelanguage="en">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN" sourcelanguage="en">
 <context>
     <name>ActionShowStashDelegate</name>
     <message>
@@ -22,4 +20,4 @@
         <translation>快捷设置</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
