@@ -1,10 +1,7 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK" sourcelanguage="en">
 <context>
     <name>ActionShowStashDelegate</name>
     <message>
-        <location filename="../package/ActionShowStashDelegate.qml" line="95"/>
         <source>Application tray</source>
         <translation>應用托盤</translation>
     </message>
@@ -12,7 +9,6 @@
 <context>
     <name>ActionToggleCollapseDelegate</name>
     <message>
-        <location filename="../package/ActionToggleCollapseDelegate.qml" line="30"/>
         <source>Collapse tray</source>
         <translation>折疊托盤</translation>
     </message>
@@ -20,9 +16,8 @@
 <context>
     <name>PanelTrayItem</name>
     <message>
-        <location filename="../quickpanel/PanelTrayItem.qml" line="30"/>
         <source>Quick actions</source>
         <translation>快速設定</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
