@@ -2,13 +2,10 @@
 <context>
     <name>notification::BubbleItem</name>
     <message>
-        <location filename="../bubbleitem.cpp" line="158"/>
-        <location filename="../bubbleitem.cpp" line="165"/>
         <source>just now</source>
         <translation>hai unsí</translation>
     </message>
     <message>
-        <location filename="../bubbleitem.cpp" line="363"/>
         <source>1 new message</source>
         <translation>1 mensaxe nova</translation>
     </message>
@@ -16,7 +13,6 @@
 <context>
     <name>notification::BubbleModel</name>
     <message>
-        <location filename="../bubblemodel.cpp" line="263"/>
         <source>%1 minutes ago</source>
         <translation>%1 minutos hoxe</translation>
     </message>
