@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>osd::DisPlayModeApplet</name>
     <message>
@@ -16,4 +14,4 @@
         <translation>Megjelenítés csak a %1-n</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
