@@ -7,25 +7,25 @@
         <source>Optimal performance</source>
         <translation>最佳性能</translation>
     </message>
-    <message>
-        <source>Optimal performance: Disable all interface and window effects for efficient system performance.</source>
-        <translation>最佳性能：关闭所有界面和窗口特效，保障系统高效运行.</translation>
-    </message>
     <message>
         <source>Balance</source>
         <translation>均衡</translation>
     </message>
-    <message>
-        <source>Balance: Limit some window effects for excellent visuals while maintaining smooth system performance.</source>
-        <translation>均衡：限制部分窗口特效，保障出色的视觉效果，同时维持系统流畅运行</translation>
-    </message>
     <message>
         <source>Best Visuals</source>
         <translation>最佳视觉</translation>
     </message>
     <message>
-        <source>Best visuals: Enable all interface and window effects for the best visual experience.</source>
-        <translation>最佳视觉：启用所有界面和窗口特效，体验最佳视觉效果</translation>
+        <source>Disable all interface and window effects for efficient system performance</source>
+        <translation>关闭所有界面和窗口特效，保障系统高效运行</translation>
+    </message>
+    <message>
+        <source>Limit some window effects for excellent visuals while maintaining smooth system performance</source>
+        <translation>限制部分窗口特效，保障出色的视觉效果，同时维持系统流畅运行</translation>
+    </message>
+    <message>
+        <source>Enable all interface and window effects for the best visual experience</source>
+        <translation>启用所有界面和窗口特效，体验最佳视觉效果</translation>
     </message>
 </context>
 </TS>
