@@ -7,6 +7,7 @@
 #include <QCommandLineParser>
 #include <QStandardPaths>
 
+#include <DApplication>
 #include <DGuiApplicationHelper>
 #include <DLog>
 #include <QQuickWindow>
@@ -24,6 +25,7 @@
 
 DS_USE_NAMESPACE
 DGUI_USE_NAMESPACE
+DWIDGET_USE_NAMESPACE
 
 DS_BEGIN_NAMESPACE
 Q_DECLARE_LOGGING_CATEGORY(dsLog)
@@ -95,7 +97,9 @@ int main(int argc, char *argv[])
 {
     setenv("DSG_APP_ID", "org.deepin.dde.shell", 0);
     DGuiApplicationHelper::setAttribute(DGuiApplicationHelper::UseInactiveColorGroup, false);
-    QApplication a(argc, argv);
+    DApplication a(argc, argv);
+    // Don't apply to plugins
+    qunsetenv("QT_SCALE_FACTOR");
     // dde-shell contains UI controls based on QML and Widget technologies.
     // Due to the inconsistency of the default font rendering methods of different schemes,
     // the font effects are not uniform.
@@ -121,6 +125,8 @@ int main(int argc, char *argv[])
     parser.addOption(listOption);
     QCommandLineOption sceneviewOption("sceneview", "View applets in scene, it only works without Window.", QString());
     parser.addOption(sceneviewOption);
+    QCommandLineOption dbusServiceNameOption("serviceName", "Registed DBus service for the serviceName, if it's not empty.", "serviceName", QString("org.deepin.dde.shell"));
+    parser.addOption(dbusServiceNameOption);
 
     parser.process(a);
 
@@ -145,6 +151,24 @@ int main(int argc, char *argv[])
     Dtk::Core::DLogManager::registerJournalAppender();
     qCInfo(dsLog) << "Log path is:" << Dtk::Core::DLogManager::getlogFilePath();
 
+    Shell shell;
+    QString serviceName(parser.value(dbusServiceNameOption));
+    if (!parser.isSet(dbusServiceNameOption)) {
+        const QString prefix(serviceName);
+        if (parser.isSet(categoryOption)) {
+            QString subfix(parser.value(categoryOption));
+            serviceName = QString("%1.%2").arg(prefix).arg(subfix);
+        } else {
+            QString subfix(QString::number(QGuiApplication::applicationPid()));
+            serviceName = QString("%1.random%2").arg(prefix).arg(subfix);
+        }
+    }
+    if (!shell.registerDBusService(serviceName)) {
+        qCFatal(dsLog).noquote() << QString("Can't start an instance for the dbus serviceName: \"%1\".").arg(serviceName);
+        return -1;
+    }
+    qCInfo(dsLog).noquote() << QStringLiteral("Register dbus service for the serviceName: \"%1\"").arg(serviceName);
+
     QList<QString> pluginIds;
     if (parser.isSet(testOption)) {
         pluginIds << "org.deepin.ds.example";
@@ -174,7 +198,6 @@ int main(int argc, char *argv[])
         });
     }
 
-    Shell shell;
     shell.dconfigsMigrate();
     // TODO disable qml's cache avoid to parsing error for ExecutionEngine.
     shell.disableQmlCache();
